Class: Rafflesia::Simulations

Inherits:
Object
  • Object
show all
Defined in:
lib/rafflesia/simulations.rb

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Simulations

Returns a new instance of Simulations.



9
10
11
# File 'lib/rafflesia/simulations.rb', line 9

def initialize(client)
  @client = client
end

Instance Method Details

#contactsNativeFraction(backend: nil, database: nil, end_frame: nil, min_seq_sep: nil, output_format: nil, output_relation: nil, partition_by: nil, preview_limit: nil, radius_angstrom: nil, reference_frame: nil, reference_structure_format: nil, reference_structure_object_id: nil, reference_structure_path: nil, relation: nil, release: nil, selection: nil, soft_cutoff_factor: nil, sort_by: nil, start_frame: nil, stride: nil, timeout_ms: nil, topology_format: nil, topology_object_id: nil, topology_path: nil, trajectory_format: nil, trajectory_manifest_object_id: nil, trajectory_object_id: nil, trajectory_path: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationNativeContactFractionTableData

POST /v1/simulations/contacts/native-fraction

Parameters:

  • backend (String, nil) (defaults to: nil)
  • database (String, nil) (defaults to: nil)

    Database name published with the relation

  • end_frame (Integer, nil) (defaults to: nil)
  • min_seq_sep (Integer, nil) (defaults to: nil)
  • output_format (Rafflesia::Types::SimulationNativeContactFractionTableRequestOutputFormat, nil) (defaults to: nil)

    Requested durable relation format; parquet is the initial physical format

  • output_relation (String, nil) (defaults to: nil)

    Local output path or alias for a durable relation artifact

  • partition_by (Array<String>, nil) (defaults to: nil)

    Requested physical partition columns

  • preview_limit (Integer, nil) (defaults to: nil)

    When output_relation is requested, include at most this many rows as a non-pageable preview

  • radius_angstrom (Float, nil) (defaults to: nil)
  • reference_frame (Integer, nil) (defaults to: nil)
  • reference_structure_format (String, nil) (defaults to: nil)
  • reference_structure_object_id (String, nil) (defaults to: nil)
  • reference_structure_path (String, nil) (defaults to: nil)
  • relation (String, nil) (defaults to: nil)

    Requested logical relation name

  • release (String, nil) (defaults to: nil)

    Immutable database release published with the relation

  • selection (String, nil) (defaults to: nil)
  • soft_cutoff_factor (Float, nil) (defaults to: nil)
  • sort_by (Array<String>, nil) (defaults to: nil)

    Requested physical sort columns

  • start_frame (Integer, nil) (defaults to: nil)
  • stride (Integer, nil) (defaults to: nil)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • topology_format (String, nil) (defaults to: nil)
  • topology_object_id (String, nil) (defaults to: nil)
  • topology_path (String, nil) (defaults to: nil)
  • trajectory_format (String, nil) (defaults to: nil)
  • trajectory_manifest_object_id (String, nil) (defaults to: nil)
  • trajectory_object_id (String, nil) (defaults to: nil)
  • trajectory_path (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/rafflesia/simulations.rb', line 44

def contactsNativeFraction(
  backend: nil,
  database: nil,
  end_frame: nil,
  min_seq_sep: nil,
  output_format: nil,
  output_relation: nil,
  partition_by: nil,
  preview_limit: nil,
  radius_angstrom: nil,
  reference_frame: nil,
  reference_structure_format: nil,
  reference_structure_object_id: nil,
  reference_structure_path: nil,
  relation: nil,
  release: nil,
  selection: nil,
  soft_cutoff_factor: nil,
  sort_by: nil,
  start_frame: nil,
  stride: nil,
  timeout_ms: nil,
  topology_format: nil,
  topology_object_id: nil,
  topology_path: nil,
  trajectory_format: nil,
  trajectory_manifest_object_id: nil,
  trajectory_object_id: nil,
  trajectory_path: nil,
  request_options: {}
)
  body = {
    'backend' => backend,
    'database' => database,
    'end_frame' => end_frame,
    'min_seq_sep' => min_seq_sep,
    'output_format' => output_format,
    'output_relation' => output_relation,
    'partition_by' => partition_by,
    'preview_limit' => preview_limit,
    'radius_angstrom' => radius_angstrom,
    'reference_frame' => reference_frame,
    'reference_structure_format' => reference_structure_format,
    'reference_structure_object_id' => reference_structure_object_id,
    'reference_structure_path' => reference_structure_path,
    'relation' => relation,
    'release' => release,
    'selection' => selection,
    'soft_cutoff_factor' => soft_cutoff_factor,
    'sort_by' => sort_by,
    'start_frame' => start_frame,
    'stride' => stride,
    'timeout_ms' => timeout_ms,
    'topology_format' => topology_format,
    'topology_object_id' => topology_object_id,
    'topology_path' => topology_path,
    'trajectory_format' => trajectory_format,
    'trajectory_manifest_object_id' => trajectory_manifest_object_id,
    'trajectory_object_id' => trajectory_object_id,
    'trajectory_path' => trajectory_path
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/contacts/native-fraction',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationNativeContactFractionTableData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#contactsRelation(backend: nil, database: nil, end_frame: nil, max_pairs: nil, output_format: nil, output_relation: nil, partition_by: nil, preview_limit: nil, radius_angstrom: nil, relation: nil, release: nil, selection_a: nil, selection_b: nil, sort_by: nil, start_frame: nil, stride: nil, timeout_ms: nil, topology_format: nil, topology_object_id: nil, topology_path: nil, trajectory_format: nil, trajectory_manifest_object_id: nil, trajectory_object_id: nil, trajectory_path: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationContactsTableData

POST /v1/simulations/contacts/relation

Parameters:

  • backend (String, nil) (defaults to: nil)
  • database (String, nil) (defaults to: nil)

    Database name published with the relation

  • end_frame (Integer, nil) (defaults to: nil)
  • max_pairs (Integer, nil) (defaults to: nil)
  • output_format (Rafflesia::Types::SimulationContactsTableRequestOutputFormat, nil) (defaults to: nil)

    Requested durable relation format; parquet is the initial physical format

  • output_relation (String, nil) (defaults to: nil)

    Local output path or alias for a durable relation artifact

  • partition_by (Array<String>, nil) (defaults to: nil)

    Requested physical partition columns

  • preview_limit (Integer, nil) (defaults to: nil)

    When output_relation is requested, include at most this many rows as a non-pageable preview

  • radius_angstrom (Float, nil) (defaults to: nil)
  • relation (String, nil) (defaults to: nil)

    Requested logical relation name

  • release (String, nil) (defaults to: nil)

    Immutable database release published with the relation

  • selection_a (String, nil) (defaults to: nil)
  • selection_b (String, nil) (defaults to: nil)
  • sort_by (Array<String>, nil) (defaults to: nil)

    Requested physical sort columns

  • start_frame (Integer, nil) (defaults to: nil)
  • stride (Integer, nil) (defaults to: nil)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • topology_format (String, nil) (defaults to: nil)
  • topology_object_id (String, nil) (defaults to: nil)
  • topology_path (String, nil) (defaults to: nil)
  • trajectory_format (String, nil) (defaults to: nil)
  • trajectory_manifest_object_id (String, nil) (defaults to: nil)
  • trajectory_object_id (String, nil) (defaults to: nil)
  • trajectory_path (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/rafflesia/simulations.rb', line 144

def contactsRelation(
  backend: nil,
  database: nil,
  end_frame: nil,
  max_pairs: nil,
  output_format: nil,
  output_relation: nil,
  partition_by: nil,
  preview_limit: nil,
  radius_angstrom: nil,
  relation: nil,
  release: nil,
  selection_a: nil,
  selection_b: nil,
  sort_by: nil,
  start_frame: nil,
  stride: nil,
  timeout_ms: nil,
  topology_format: nil,
  topology_object_id: nil,
  topology_path: nil,
  trajectory_format: nil,
  trajectory_manifest_object_id: nil,
  trajectory_object_id: nil,
  trajectory_path: nil,
  request_options: {}
)
  body = {
    'backend' => backend,
    'database' => database,
    'end_frame' => end_frame,
    'max_pairs' => max_pairs,
    'output_format' => output_format,
    'output_relation' => output_relation,
    'partition_by' => partition_by,
    'preview_limit' => preview_limit,
    'radius_angstrom' => radius_angstrom,
    'relation' => relation,
    'release' => release,
    'selection_a' => selection_a,
    'selection_b' => selection_b,
    'sort_by' => sort_by,
    'start_frame' => start_frame,
    'stride' => stride,
    'timeout_ms' => timeout_ms,
    'topology_format' => topology_format,
    'topology_object_id' => topology_object_id,
    'topology_path' => topology_path,
    'trajectory_format' => trajectory_format,
    'trajectory_manifest_object_id' => trajectory_manifest_object_id,
    'trajectory_object_id' => trajectory_object_id,
    'trajectory_path' => trajectory_path
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/contacts/relation',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationContactsTableData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#gromacsCheckInputs(script_object_id:, max_bytes: nil, root_object_ids: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationGromacsCheckInputsData

POST /v1/simulations/gromacs/check-inputs

Parameters:

  • max_bytes (Integer, nil) (defaults to: nil)
  • root_object_ids (Array<String>, nil) (defaults to: nil)

    Objects containing material inventories, for example GitHub contents JSON arrays. Repeat roots to cover multiple directories.

  • script_object_id (String)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/rafflesia/simulations.rb', line 215

def gromacsCheckInputs(
  script_object_id:,
  max_bytes: nil,
  root_object_ids: nil,
  request_options: {}
)
  body = {
    'max_bytes' => max_bytes,
    'root_object_ids' => root_object_ids,
    'script_object_id' => script_object_id
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/gromacs/check-inputs',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationGromacsCheckInputsData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#gromacsInspectMdp(mdp_object_id:, max_bytes: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationGromacsInspectMdpData

POST /v1/simulations/gromacs/inspect-mdp

Parameters:

  • max_bytes (Integer, nil) (defaults to: nil)
  • mdp_object_id (String)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/rafflesia/simulations.rb', line 243

def gromacsInspectMdp(
  mdp_object_id:,
  max_bytes: nil,
  request_options: {}
)
  body = {
    'max_bytes' => max_bytes,
    'mdp_object_id' => mdp_object_id
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/gromacs/inspect-mdp',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationGromacsInspectMdpData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#gromacsInspectScript(script_object_id:, max_bytes: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationGromacsInspectScriptData

POST /v1/simulations/gromacs/inspect-script

Parameters:

  • max_bytes (Integer, nil) (defaults to: nil)
  • script_object_id (String)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/rafflesia/simulations.rb', line 269

def gromacsInspectScript(
  script_object_id:,
  max_bytes: nil,
  request_options: {}
)
  body = {
    'max_bytes' => max_bytes,
    'script_object_id' => script_object_id
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/gromacs/inspect-script',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationGromacsInspectScriptData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#gromacsMaterializeInputs(output_dir:, allow_network: nil, input_object_ids: nil, max_bytes: nil, max_download_bytes: nil, preflight_object_id: nil, root_object_ids: nil, script_object_id: nil, stage_index: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationGromacsMaterializeInputsData

POST /v1/simulations/gromacs/materialize-inputs

Parameters:

  • allow_network (Boolean, nil) (defaults to: nil)

    Allow resolved inventory download_url values to be fetched into the object store when no object id is available.

  • input_object_ids (Hash{String => String}, nil) (defaults to: nil)

    Optional explicit mapping from requested input path to object id, used for planned outputs from earlier stages or inventories without object ids.

  • max_bytes (Integer, nil) (defaults to: nil)
  • max_download_bytes (Integer, nil) (defaults to: nil)

    Maximum bytes for each network materialization. Defaults to the server object download limit.

  • output_dir (String)

    Local server directory where object-backed inputs are materialized.

  • preflight_object_id (String, nil) (defaults to: nil)

    Optional object id containing a SimulationGromacsPreflightData document or response envelope. When set, script_object_id/root_object_ids are not required.

  • root_object_ids (Array<String>, nil) (defaults to: nil)

    Objects containing material inventories used to build a preflight plan and resolve inputs.

  • script_object_id (String, nil) (defaults to: nil)

    Script object id used to build a preflight plan when preflight_object_id is omitted.

  • stage_index (Integer, nil) (defaults to: nil)

    Optional one-based preflight stage index. When omitted, materializes external required script inputs.

  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/rafflesia/simulations.rb', line 302

def gromacsMaterializeInputs(
  output_dir:,
  allow_network: nil,
  input_object_ids: nil,
  max_bytes: nil,
  max_download_bytes: nil,
  preflight_object_id: nil,
  root_object_ids: nil,
  script_object_id: nil,
  stage_index: nil,
  request_options: {}
)
  body = {
    'allow_network' => allow_network,
    'input_object_ids' => input_object_ids,
    'max_bytes' => max_bytes,
    'max_download_bytes' => max_download_bytes,
    'output_dir' => output_dir,
    'preflight_object_id' => preflight_object_id,
    'root_object_ids' => root_object_ids,
    'script_object_id' => script_object_id,
    'stage_index' => stage_index
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/gromacs/materialize-inputs',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationGromacsMaterializeInputsData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#gromacsPreflight(script_object_id:, engine: nil, max_bytes: nil, root_object_ids: nil, timeout_ms: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationGromacsPreflightData

POST /v1/simulations/gromacs/preflight

Parameters:

  • engine (Rafflesia::Types::SimulationGromacsPreflightRequestEngine, nil) (defaults to: nil)

    Simulation engine to preflight. Defaults to gromacs.

  • max_bytes (Integer, nil) (defaults to: nil)
  • root_object_ids (Array<String>, nil) (defaults to: nil)

    Objects containing material inventories, for example GitHub contents JSON arrays. Repeat roots to cover multiple directories.

  • script_object_id (String)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/rafflesia/simulations.rb', line 345

def gromacsPreflight(
  script_object_id:,
  engine: nil,
  max_bytes: nil,
  root_object_ids: nil,
  timeout_ms: nil,
  request_options: {}
)
  body = {
    'engine' => engine,
    'max_bytes' => max_bytes,
    'root_object_ids' => root_object_ids,
    'script_object_id' => script_object_id,
    'timeout_ms' => timeout_ms
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/gromacs/preflight',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationGromacsPreflightData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#gromacsRunStage(output_dir:, stage_index:, gromacs_binary_path: nil, input_object_ids: nil, max_bytes: nil, max_log_bytes: nil, preflight_object_id: nil, root_object_ids: nil, script_object_id: nil, stdin: nil, timeout_ms: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationGromacsRunStageData

POST /v1/simulations/gromacs/run-stage

Parameters:

  • gromacs_binary_path (String, nil) (defaults to: nil)

    Optional explicit Gromacs executable. Defaults to RAFFLESIA_GROMACS_BINARY or PATH.

  • input_object_ids (Hash{String => String}, nil) (defaults to: nil)

    Optional explicit mapping from requested stage input path to object id, used for planned outputs from earlier stages or inventories without object ids.

  • max_bytes (Integer, nil) (defaults to: nil)
  • max_log_bytes (Integer, nil) (defaults to: nil)
  • output_dir (String)

    Local server directory where the bounded stage working directory and output files are written.

  • preflight_object_id (String, nil) (defaults to: nil)

    Optional object id containing a SimulationGromacsPreflightData document or response envelope. When set, script_object_id/root_object_ids are not required.

  • root_object_ids (Array<String>, nil) (defaults to: nil)

    Objects containing material inventories used to build a preflight plan and materialize stage inputs.

  • script_object_id (String, nil) (defaults to: nil)

    Script object id used to build a preflight plan when preflight_object_id is omitted.

  • stage_index (Integer)

    One-based preflight stage index to execute.

  • stdin (String, nil) (defaults to: nil)

    Optional stdin supplied to the stage command, for example make_ndx selections.

  • timeout_ms (Integer, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/rafflesia/simulations.rb', line 386

def gromacsRunStage(
  output_dir:,
  stage_index:,
  gromacs_binary_path: nil,
  input_object_ids: nil,
  max_bytes: nil,
  max_log_bytes: nil,
  preflight_object_id: nil,
  root_object_ids: nil,
  script_object_id: nil,
  stdin: nil,
  timeout_ms: nil,
  request_options: {}
)
  body = {
    'gromacs_binary_path' => gromacs_binary_path,
    'input_object_ids' => input_object_ids,
    'max_bytes' => max_bytes,
    'max_log_bytes' => max_log_bytes,
    'output_dir' => output_dir,
    'preflight_object_id' => preflight_object_id,
    'root_object_ids' => root_object_ids,
    'script_object_id' => script_object_id,
    'stage_index' => stage_index,
    'stdin' => stdin,
    'timeout_ms' => timeout_ms
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/gromacs/run-stage',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationGromacsRunStageData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#runtimeBootstrap(install:, force_recreate: nil, output_dir: nil, packages: nil, python_path: nil, timeout_ms: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationRuntimeBootstrapData

POST /v1/simulations/runtime/bootstrap

Parameters:

  • force_recreate (Boolean, nil) (defaults to: nil)

    Remove and recreate the output_dir before bootstrapping.

  • install (Boolean)

    Install requested packages into the virtual environment after creation.

  • output_dir (String, nil) (defaults to: nil)

    Local directory for the simulation Python virtual environment. Defaults to .evidence/simulations/mdanalysis-venv when called from the repo.

  • packages (Array<String>, nil) (defaults to: nil)

    Python packages to install when install is true. Defaults to MDAnalysis.

  • python_path (String, nil) (defaults to: nil)

    Python executable used to create the virtual environment. Defaults to python3 on PATH.

  • timeout_ms (Integer, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/rafflesia/simulations.rb', line 434

def runtimeBootstrap(
  install:,
  force_recreate: nil,
  output_dir: nil,
  packages: nil,
  python_path: nil,
  timeout_ms: nil,
  request_options: {}
)
  body = {
    'force_recreate' => force_recreate,
    'install' => install,
    'output_dir' => output_dir,
    'packages' => packages,
    'python_path' => python_path,
    'timeout_ms' => timeout_ms
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/runtime/bootstrap',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationRuntimeBootstrapData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#runtimeInspect(engine: nil, timeout_ms: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationRuntimeInspectData

POST /v1/simulations/runtime/inspect

Parameters:

  • engine (Rafflesia::Types::SimulationRuntimeInspectRequestEngine, nil) (defaults to: nil)

    Runtime engine to inspect. Defaults to all available simulation runtimes.

  • timeout_ms (Integer, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/rafflesia/simulations.rb', line 468

def runtimeInspect(
  engine: nil,
  timeout_ms: nil,
  request_options: {}
)
  body = {
    'engine' => engine,
    'timeout_ms' => timeout_ms
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/runtime/inspect',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationRuntimeInspectData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#trajectoriesFramesRelation(backend: nil, database: nil, end_frame: nil, output_format: nil, output_relation: nil, partition_by: nil, preview_limit: nil, relation: nil, release: nil, sort_by: nil, start_frame: nil, stride: nil, timeout_ms: nil, topology_format: nil, topology_object_id: nil, topology_path: nil, trajectory_format: nil, trajectory_manifest_object_id: nil, trajectory_object_id: nil, trajectory_path: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationTrajectoryFramesTableData

POST /v1/simulations/trajectories/frames/relation

Parameters:

  • backend (String, nil) (defaults to: nil)
  • database (String, nil) (defaults to: nil)

    Database name published with the relation

  • end_frame (Integer, nil) (defaults to: nil)
  • output_format (Rafflesia::Types::SimulationTrajectoryFramesTableRequestOutputFormat, nil) (defaults to: nil)

    Requested durable relation format; parquet is the initial physical format

  • output_relation (String, nil) (defaults to: nil)

    Local output path or alias for a durable relation artifact

  • partition_by (Array<String>, nil) (defaults to: nil)

    Requested physical partition columns

  • preview_limit (Integer, nil) (defaults to: nil)

    When output_relation is requested, include at most this many rows as a non-pageable preview

  • relation (String, nil) (defaults to: nil)

    Requested logical relation name

  • release (String, nil) (defaults to: nil)

    Immutable database release published with the relation

  • sort_by (Array<String>, nil) (defaults to: nil)

    Requested physical sort columns

  • start_frame (Integer, nil) (defaults to: nil)
  • stride (Integer, nil) (defaults to: nil)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • topology_format (String, nil) (defaults to: nil)
  • topology_object_id (String, nil) (defaults to: nil)
  • topology_path (String, nil) (defaults to: nil)
  • trajectory_format (String, nil) (defaults to: nil)
  • trajectory_manifest_object_id (String, nil) (defaults to: nil)
  • trajectory_object_id (String, nil) (defaults to: nil)
  • trajectory_path (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
# File 'lib/rafflesia/simulations.rb', line 512

def trajectoriesFramesRelation(
  backend: nil,
  database: nil,
  end_frame: nil,
  output_format: nil,
  output_relation: nil,
  partition_by: nil,
  preview_limit: nil,
  relation: nil,
  release: nil,
  sort_by: nil,
  start_frame: nil,
  stride: nil,
  timeout_ms: nil,
  topology_format: nil,
  topology_object_id: nil,
  topology_path: nil,
  trajectory_format: nil,
  trajectory_manifest_object_id: nil,
  trajectory_object_id: nil,
  trajectory_path: nil,
  request_options: {}
)
  body = {
    'backend' => backend,
    'database' => database,
    'end_frame' => end_frame,
    'output_format' => output_format,
    'output_relation' => output_relation,
    'partition_by' => partition_by,
    'preview_limit' => preview_limit,
    'relation' => relation,
    'release' => release,
    'sort_by' => sort_by,
    'start_frame' => start_frame,
    'stride' => stride,
    'timeout_ms' => timeout_ms,
    'topology_format' => topology_format,
    'topology_object_id' => topology_object_id,
    'topology_path' => topology_path,
    'trajectory_format' => trajectory_format,
    'trajectory_manifest_object_id' => trajectory_manifest_object_id,
    'trajectory_object_id' => trajectory_object_id,
    'trajectory_path' => trajectory_path
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/trajectories/frames/relation',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationTrajectoryFramesTableData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#trajectoriesGeometryRelation(backend: nil, database: nil, end_frame: nil, output_format: nil, output_relation: nil, partition_by: nil, preview_limit: nil, relation: nil, release: nil, selection: nil, sort_by: nil, start_frame: nil, stride: nil, timeout_ms: nil, topology_format: nil, topology_object_id: nil, topology_path: nil, trajectory_format: nil, trajectory_manifest_object_id: nil, trajectory_object_id: nil, trajectory_path: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationTrajectoryGeometryTableData

POST /v1/simulations/trajectories/geometry/relation

Parameters:

  • backend (String, nil) (defaults to: nil)
  • database (String, nil) (defaults to: nil)

    Database name published with the relation

  • end_frame (Integer, nil) (defaults to: nil)
  • output_format (Rafflesia::Types::SimulationTrajectoryGeometryTableRequestOutputFormat, nil) (defaults to: nil)

    Requested durable relation format; parquet is the initial physical format

  • output_relation (String, nil) (defaults to: nil)

    Local output path or alias for a durable relation artifact

  • partition_by (Array<String>, nil) (defaults to: nil)

    Requested physical partition columns

  • preview_limit (Integer, nil) (defaults to: nil)

    When output_relation is requested, include at most this many rows as a non-pageable preview

  • relation (String, nil) (defaults to: nil)

    Requested logical relation name

  • release (String, nil) (defaults to: nil)

    Immutable database release published with the relation

  • selection (String, nil) (defaults to: nil)
  • sort_by (Array<String>, nil) (defaults to: nil)

    Requested physical sort columns

  • start_frame (Integer, nil) (defaults to: nil)
  • stride (Integer, nil) (defaults to: nil)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • topology_format (String, nil) (defaults to: nil)
  • topology_object_id (String, nil) (defaults to: nil)
  • topology_path (String, nil) (defaults to: nil)
  • trajectory_format (String, nil) (defaults to: nil)
  • trajectory_manifest_object_id (String, nil) (defaults to: nil)
  • trajectory_object_id (String, nil) (defaults to: nil)
  • trajectory_path (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
# File 'lib/rafflesia/simulations.rb', line 593

def trajectoriesGeometryRelation(
  backend: nil,
  database: nil,
  end_frame: nil,
  output_format: nil,
  output_relation: nil,
  partition_by: nil,
  preview_limit: nil,
  relation: nil,
  release: nil,
  selection: nil,
  sort_by: nil,
  start_frame: nil,
  stride: nil,
  timeout_ms: nil,
  topology_format: nil,
  topology_object_id: nil,
  topology_path: nil,
  trajectory_format: nil,
  trajectory_manifest_object_id: nil,
  trajectory_object_id: nil,
  trajectory_path: nil,
  request_options: {}
)
  body = {
    'backend' => backend,
    'database' => database,
    'end_frame' => end_frame,
    'output_format' => output_format,
    'output_relation' => output_relation,
    'partition_by' => partition_by,
    'preview_limit' => preview_limit,
    'relation' => relation,
    'release' => release,
    'selection' => selection,
    'sort_by' => sort_by,
    'start_frame' => start_frame,
    'stride' => stride,
    'timeout_ms' => timeout_ms,
    'topology_format' => topology_format,
    'topology_object_id' => topology_object_id,
    'topology_path' => topology_path,
    'trajectory_format' => trajectory_format,
    'trajectory_manifest_object_id' => trajectory_manifest_object_id,
    'trajectory_object_id' => trajectory_object_id,
    'trajectory_path' => trajectory_path
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/trajectories/geometry/relation',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationTrajectoryGeometryTableData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#trajectoriesImport(backend: nil, timeout_ms: nil, topology_format: nil, topology_object_id: nil, topology_path: nil, trajectory_format: nil, trajectory_object_id: nil, trajectory_path: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationTrajectoryImportData

POST /v1/simulations/trajectories/import

Parameters:

  • backend (String, nil) (defaults to: nil)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • topology_format (String, nil) (defaults to: nil)
  • topology_object_id (String, nil) (defaults to: nil)
  • topology_path (String, nil) (defaults to: nil)
  • trajectory_format (String, nil) (defaults to: nil)
  • trajectory_object_id (String, nil) (defaults to: nil)
  • trajectory_path (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
# File 'lib/rafflesia/simulations.rb', line 663

def trajectoriesImport(
  backend: nil,
  timeout_ms: nil,
  topology_format: nil,
  topology_object_id: nil,
  topology_path: nil,
  trajectory_format: nil,
  trajectory_object_id: nil,
  trajectory_path: nil,
  request_options: {}
)
  body = {
    'backend' => backend,
    'timeout_ms' => timeout_ms,
    'topology_format' => topology_format,
    'topology_object_id' => topology_object_id,
    'topology_path' => topology_path,
    'trajectory_format' => trajectory_format,
    'trajectory_object_id' => trajectory_object_id,
    'trajectory_path' => trajectory_path
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/trajectories/import',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationTrajectoryImportData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#trajectoriesInspect(backend: nil, timeout_ms: nil, topology_format: nil, topology_object_id: nil, topology_path: nil, trajectory_format: nil, trajectory_manifest_object_id: nil, trajectory_object_id: nil, trajectory_path: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationTrajectoryInspectData

POST /v1/simulations/trajectories/inspect

Parameters:

  • backend (String, nil) (defaults to: nil)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • topology_format (String, nil) (defaults to: nil)
  • topology_object_id (String, nil) (defaults to: nil)
  • topology_path (String, nil) (defaults to: nil)
  • trajectory_format (String, nil) (defaults to: nil)
  • trajectory_manifest_object_id (String, nil) (defaults to: nil)
  • trajectory_object_id (String, nil) (defaults to: nil)
  • trajectory_path (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
# File 'lib/rafflesia/simulations.rb', line 708

def trajectoriesInspect(
  backend: nil,
  timeout_ms: nil,
  topology_format: nil,
  topology_object_id: nil,
  topology_path: nil,
  trajectory_format: nil,
  trajectory_manifest_object_id: nil,
  trajectory_object_id: nil,
  trajectory_path: nil,
  request_options: {}
)
  body = {
    'backend' => backend,
    'timeout_ms' => timeout_ms,
    'topology_format' => topology_format,
    'topology_object_id' => topology_object_id,
    'topology_path' => topology_path,
    'trajectory_format' => trajectory_format,
    'trajectory_manifest_object_id' => trajectory_manifest_object_id,
    'trajectory_object_id' => trajectory_object_id,
    'trajectory_path' => trajectory_path
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/trajectories/inspect',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationTrajectoryInspectData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end

#trajectoriesRmsdRelation(backend: nil, database: nil, end_frame: nil, output_format: nil, output_relation: nil, partition_by: nil, preview_limit: nil, reference_frame: nil, reference_structure_format: nil, reference_structure_object_id: nil, reference_structure_path: nil, relation: nil, release: nil, selection: nil, sort_by: nil, start_frame: nil, stride: nil, superpose: nil, timeout_ms: nil, topology_format: nil, topology_object_id: nil, topology_path: nil, trajectory_format: nil, trajectory_manifest_object_id: nil, trajectory_object_id: nil, trajectory_path: nil, request_options: {}) ⇒ Rafflesia::EnvelopeSimulationTrajectoryRmsdTableData

POST /v1/simulations/trajectories/rmsd/relation

Parameters:

  • backend (String, nil) (defaults to: nil)
  • database (String, nil) (defaults to: nil)

    Database name published with the relation

  • end_frame (Integer, nil) (defaults to: nil)
  • output_format (Rafflesia::Types::SimulationTrajectoryRmsdTableRequestOutputFormat, nil) (defaults to: nil)

    Requested durable relation format; parquet is the initial physical format

  • output_relation (String, nil) (defaults to: nil)

    Local output path or alias for a durable relation artifact

  • partition_by (Array<String>, nil) (defaults to: nil)

    Requested physical partition columns

  • preview_limit (Integer, nil) (defaults to: nil)

    When output_relation is requested, include at most this many rows as a non-pageable preview

  • reference_frame (Integer, nil) (defaults to: nil)
  • reference_structure_format (String, nil) (defaults to: nil)
  • reference_structure_object_id (String, nil) (defaults to: nil)
  • reference_structure_path (String, nil) (defaults to: nil)
  • relation (String, nil) (defaults to: nil)

    Requested logical relation name

  • release (String, nil) (defaults to: nil)

    Immutable database release published with the relation

  • selection (String, nil) (defaults to: nil)
  • sort_by (Array<String>, nil) (defaults to: nil)

    Requested physical sort columns

  • start_frame (Integer, nil) (defaults to: nil)
  • stride (Integer, nil) (defaults to: nil)
  • superpose (Boolean, nil) (defaults to: nil)
  • timeout_ms (Integer, nil) (defaults to: nil)
  • topology_format (String, nil) (defaults to: nil)
  • topology_object_id (String, nil) (defaults to: nil)
  • topology_path (String, nil) (defaults to: nil)
  • trajectory_format (String, nil) (defaults to: nil)
  • trajectory_manifest_object_id (String, nil) (defaults to: nil)
  • trajectory_object_id (String, nil) (defaults to: nil)
  • trajectory_path (String, nil) (defaults to: nil)
  • request_options (Hash) (defaults to: {})

    (see Rafflesia::Types::RequestOptions)

Returns:



772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
# File 'lib/rafflesia/simulations.rb', line 772

def trajectoriesRmsdRelation(
  backend: nil,
  database: nil,
  end_frame: nil,
  output_format: nil,
  output_relation: nil,
  partition_by: nil,
  preview_limit: nil,
  reference_frame: nil,
  reference_structure_format: nil,
  reference_structure_object_id: nil,
  reference_structure_path: nil,
  relation: nil,
  release: nil,
  selection: nil,
  sort_by: nil,
  start_frame: nil,
  stride: nil,
  superpose: nil,
  timeout_ms: nil,
  topology_format: nil,
  topology_object_id: nil,
  topology_path: nil,
  trajectory_format: nil,
  trajectory_manifest_object_id: nil,
  trajectory_object_id: nil,
  trajectory_path: nil,
  request_options: {}
)
  body = {
    'backend' => backend,
    'database' => database,
    'end_frame' => end_frame,
    'output_format' => output_format,
    'output_relation' => output_relation,
    'partition_by' => partition_by,
    'preview_limit' => preview_limit,
    'reference_frame' => reference_frame,
    'reference_structure_format' => reference_structure_format,
    'reference_structure_object_id' => reference_structure_object_id,
    'reference_structure_path' => reference_structure_path,
    'relation' => relation,
    'release' => release,
    'selection' => selection,
    'sort_by' => sort_by,
    'start_frame' => start_frame,
    'stride' => stride,
    'superpose' => superpose,
    'timeout_ms' => timeout_ms,
    'topology_format' => topology_format,
    'topology_object_id' => topology_object_id,
    'topology_path' => topology_path,
    'trajectory_format' => trajectory_format,
    'trajectory_manifest_object_id' => trajectory_manifest_object_id,
    'trajectory_object_id' => trajectory_object_id,
    'trajectory_path' => trajectory_path
  }.compact
  response = @client.request(
    method: :post,
    path: '/v1/simulations/trajectories/rmsd/relation',
    auth: true,
    body: body,
    request_options: request_options
  )
  result = Rafflesia::EnvelopeSimulationTrajectoryRmsdTableData.new(response.body)
  result.last_response = Rafflesia::Types::ApiResponse.new(http_status: response.code.to_i, http_headers: response.each_header.to_h, request_id: response["x-request-id"])
  result
end